package mainview;

import java.awt.event.KeyEvent;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPanel;

import ui.CloseListener;
import ui.CloseableJFrame;

import core.Engine;
import core.Preset;

public class MainView extends CloseableJFrame {
	private static final long serialVersionUID = 1L;
	private PresetInfoPanel infoPanel;
	private Actions actions;

	public MainView() {
		super( Engine.NAME );
		actions = new Actions( this );
		CloseListener.addCloseListener( this, false );
		buildMenu();
		buildMainView();
		showMainView();
	}
	
	private void buildMainView() {
		JPanel content = new JPanel();
		content.setLayout( new BoxLayout( content, BoxLayout.PAGE_AXIS ) );
		
		content.add( infoPanel = new PresetInfoPanel() );
		
		JPanel controlPanel = new JPanel();
		controlPanel.add( new JButton( actions.runPresetAction ) );
		controlPanel.add( new JLabel( "Original created by SYNeR." ) );
		content.add( controlPanel );
		
		getContentPane().add( content );
		pack();
	}
	
	private void showMainView() {
		setVisible( true );
	}
	
	private void buildMenu() {
		JMenuBar menuBar = new JMenuBar();
		
		JMenu fileMenu = makeMenu( "File", KeyEvent.VK_F );
		fileMenu.add( new JMenuItem( actions.openPresetAction ) );
		fileMenu.addSeparator();
		fileMenu.add( new JMenuItem( actions.exitAction ) );
		menuBar.add( fileMenu );
		
		JMenu optionsMenu = makeMenu( "Options", KeyEvent.VK_O );
		addCheckBoxMenuItem( optionsMenu, actions.forceFullScreenAction );
		addCheckBoxMenuItem( optionsMenu, actions.stretchImagesAction );
		optionsMenu.add( new JMenuItem( actions.backgroundAction ) );
		addCheckBoxMenuItem( optionsMenu, actions.audioAction );
		optionsMenu.add( new JMenuItem( actions.maxNrImagesAction ) );
		addCheckBoxMenuItem( optionsMenu, actions.autorunAction );
		optionsMenu.add( new JMenuItem( actions.minTimePerPicAction ) );
		optionsMenu.add( new JMenuItem( actions.durationAction ) );
		optionsMenu.addSeparator();
		optionsMenu.add( new JMenuItem( actions.resetSettingsAction ) );
		menuBar.add( optionsMenu );
		
		JMenu helpMenu = makeMenu( "Help", KeyEvent.VK_H );
		helpMenu.add( actions.helpAction );
		helpMenu.addSeparator();
		helpMenu.add( actions.aboutAction );
		menuBar.add( helpMenu );
		
		setJMenuBar( menuBar );
	}
	
	@Override
	public void close() {
		Engine.saveSettings();
		System.exit( 0 );
	}
	
	public void setPreset( Preset preset ) {
		infoPanel.setPreset( preset );
	}
	
	private JMenu makeMenu( String text, int mnemonic ) {
		JMenu menu = new JMenu( text );
		menu.setMnemonic( mnemonic );
		return menu;
	}
	
	private void addCheckBoxMenuItem( JMenu menu, Actions.BooleanAction checkBoxAction ) {
		JCheckBoxMenuItem item = new JCheckBoxMenuItem( checkBoxAction );
		item.setState( checkBoxAction.getState() );
		menu.add( item );
	}
}
