package mainview;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import core.Preset;

public class PresetInfoPanel extends JPanel {
	private static final long serialVersionUID = 1L;
	private JTextArea name, author, website, email;
	private JTextArea description; 
	private AvatarPanel avatar;
	
	public PresetInfoPanel() {
		super( new GridBagLayout() );
		addComponent( name = makeDisplayTextArea( 1, 35 ), 0, 0, 3, 1 );
		
		addComponent( new JLabel( "Author : " ), 0, 1 );
		addComponent( author = makeDisplayTextArea( 1, 20 ), 1, 1 );
		author.setColumns( 15 );
		
		addComponent( new JLabel( "Website : " ), 0, 2 );
		addComponent( website = makeDisplayTextArea( 1, 20 ), 1, 2 );
		website.setColumns( 15 );
		
		addComponent( new JLabel( "Email : " ), 0, 3 );
		addComponent( email = makeDisplayTextArea( 1, 20 ), 1, 3 );
		email.setColumns( 15 );
		
		addComponent( avatar = new AvatarPanel(), 2, 1, 1, 3 );
		
		description = makeDisplayTextArea( 10, 35 );
		JScrollPane descriptionScrollPane = new JScrollPane( description );
		descriptionScrollPane.setVerticalScrollBarPolicy( JScrollPane.VERTICAL_SCROLLBAR_ALWAYS );
		addComponent( descriptionScrollPane, 0, 4, 3, 1 );
		description.setRows( 8 );
	}
	
	public void setPreset( Preset preset ) {
		name.setText( preset != null ? preset.getName() : "" );
		author.setText( preset != null ? preset.getAuthor() : "" );
		website.setText( preset != null ? preset.getWebsite() : "" );
		email.setText( preset != null ? preset.getEmail() : "" );
		description.setText( preset != null ? preset.getDescription() : "" );
		description.setCaretPosition( 0 );
		avatar.setImage( preset != null ? preset.getAvatar() : null );
	}
	
	private void addComponent( JComponent component, int x, int y ) {
		addComponent( component, x, y, 1, 1 );
	}
	private void addComponent( JComponent component, int x, int y, int width, int height ) {
		GridBagConstraints c = new GridBagConstraints();
		c.gridx = x;
		c.gridy = y;
		c.gridwidth = width;
		c.gridheight = height;
		c.fill = GridBagConstraints.BOTH;
		if( width > 1 || height > 1 )
			c.insets = new Insets( 5, 5, 5, 5 );
		else
			c.insets = new Insets( 5, 5, 20, 20 );
		add( component, c );
	}
	private JTextArea makeDisplayTextArea( int rows, int columns ) {
		JTextArea res = new JTextArea();
		if( rows > 1 ) {
			res.setLineWrap( true );
			res.setWrapStyleWord( true );
		} else {
			res.setPreferredSize( new Dimension( 10 * columns, 20 * rows ) );
			res.setMinimumSize( new Dimension( 10 * columns, 20 * rows ) );
		}
		res.setEditable( false );
		res.setColumns( columns );
		res.setRows( rows );
		return res;
	}
	
	private static class AvatarPanel extends JPanel {
		private static final long serialVersionUID = 1L;
		
		private static final int width=125, height=125;
		private static final Dimension DIMENSION = new Dimension( width, height );
		private static final Color BACKGROUND = Color.white;
		
		private BufferedImage image;
		
		public AvatarPanel() {
			setSize( DIMENSION );
			setMinimumSize( DIMENSION );
			setMaximumSize( DIMENSION );
			setBackground( BACKGROUND );
		}
		
		public void setImage( File img ) {
			image = null;
			
			if( img != null ) {
				try {
					image = ImageIO.read( img );
				} catch ( IOException e ) {
					//ignore
				}
			}
			
			repaint();
		}
		
		public void paintComponent( Graphics g ) {
			g.setColor( BACKGROUND );
			if( image != null )
				g.drawImage( image, 0, 0, width, height, null );
			else
				g.fillRect( 0, 0, width, height );
		}
		
		public Dimension getPreferredSize() {
			return DIMENSION;
		}
	}
}
