package presetview;
import java.awt.Dimension;
import java.awt.GraphicsEnvironment;
import java.awt.Toolkit;

import sound.SoundPlayer;
import ui.CloseListener;
import ui.CloseableJFrame;

import core.Engine;
import core.Preset;


public class PresetView extends CloseableJFrame {
	private static final long serialVersionUID = 1L;
	private Preset preset;
	private SoundPlayer soundPlayer;
	private PresetImagePanel imagePanel;
	
	public PresetView( Preset preset ) {
		super( Engine.NAME );
		this.preset = preset;
		this.soundPlayer = new SoundPlayer( preset );
		CloseListener.addCloseListener( this, true );
		buildPresetView();
		showPresetView();		
	}
	
	public void close() {
		soundPlayer.stopPlaying();
		setVisible( false );
		imagePanel.stop();
		dispose();
	}
	
	private void buildPresetView() {
		imagePanel = new PresetImagePanel( preset );
		getContentPane().add( imagePanel );
	}
	
	private void showPresetView() {
		if( preset.isFullScreen() || Engine.getSettings().isForceFullscreen() ) {
			setUndecorated( true );
			GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().setFullScreenWindow( this );
		} else {
			pack();
			Dimension maxWindowSize = preset.getMaxWinSize();
			if( maxWindowSize == null )
				maxWindowSize = Toolkit.getDefaultToolkit().getScreenSize();
			setSize( maxWindowSize );
			validate();
		}
		
		this.setVisible( true );
		imagePanel.start();
		soundPlayer.startPlaying();
		
		int maxMinutes = Engine.getSettings().getDuration();
		if( maxMinutes > 0 ) {
			final long stop = System.currentTimeMillis() + ( maxMinutes * 60 * 1000 );
			new Thread() {
				public void run() {
					while( stop >= System.currentTimeMillis() ) {
						try {
							sleep( 1000 );//stop time doesn't have to be very accurate
						} catch (InterruptedException e) {
							//ignore
						}
					}
					close();
				}
			}.start();
		}
	}
}
