package sound;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import javazoom.jl.decoder.JavaLayerException;
import javazoom.jl.player.Player;

import core.Engine;
import core.Preset;

public class SoundPlayer {
	private File audio;
	private Player player;
	
	public SoundPlayer( Preset preset ) {
		audio = preset.getAudio();
	}
	
	public void initialize() {
		if( audio == null || !Engine.getSettings().isAudio() )
			return;
		
		FileInputStream fis = null;
		try {
			fis = new FileInputStream( audio );
		} catch( FileNotFoundException fnfe ) {
			System.out.println( "FileNotFoundException while opening audio file " + audio.getAbsolutePath() + " : " + fnfe.getMessage() );
			fnfe.printStackTrace();
			return;
		}
			
		player = null;
		try {
			player = new Player( fis );
		} catch( JavaLayerException jle ) {
			System.out.println( "Java Layer Exception while reading audio file " + audio.getAbsolutePath() + " : " + jle.getMessage() );
			jle.printStackTrace();
			return;
		} catch( Throwable t ) {
			System.out.println( "Unknown Exception while reading " + audio.getAbsolutePath() + " : " + t.getMessage() );
			t.printStackTrace();
		}
	}
	
	public void startPlaying() {
		initialize();
		if( player != null ) {
			new Thread() {
				public void run() {
					try {
						player.play();
					} catch( Throwable t ) {
						System.out.println( "Error while playing audio file " + audio.getAbsolutePath() + " : " + t.getMessage() );
						t.printStackTrace();
					}
				}
			}.start();
		}
	}
	
	public void stopPlaying() {
		if( player != null ) {
			player.close();
			player = null;
		}
	}
}
