package ui;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

import javax.swing.JFrame;

public class CloseListener<T extends CloseableJFrame> implements MouseListener, KeyListener, WindowListener {
	private T close;
	private boolean closeEasily;
	
	private CloseListener( T close, boolean closeEasily ) {
		this.close = close;
		this.closeEasily = closeEasily;
	}
	
	public static void addCloseListener( CloseableJFrame close, boolean closeEasily ) {
		CloseListener<CloseableJFrame> closeListener = new CloseListener<CloseableJFrame>( close, closeEasily );
		close.setDefaultCloseOperation ( JFrame.DO_NOTHING_ON_CLOSE );
		close.addMouseListener( closeListener );
		close.addKeyListener( closeListener );
		close.addWindowListener( closeListener );
	}
	
	protected void close() {
		close.close();
	}
	
	@Override
	public void mouseClicked(MouseEvent arg0) {
		if( closeEasily )
			close();
	}

	@Override
	public void mouseEntered(MouseEvent arg0) {
		//nothing
	}

	@Override
	public void mouseExited(MouseEvent arg0) {
		//nothing
	}

	@Override
	public void mousePressed(MouseEvent arg0) {
		if( closeEasily )
			close();
	}

	@Override
	public void mouseReleased(MouseEvent arg0) {
		//nothing
	}

	@Override
	public void keyPressed(KeyEvent e) {
		if( closeEasily && e.getKeyCode() == KeyEvent.VK_ESCAPE )
			close();
	}

	@Override
	public void keyReleased(KeyEvent e) {
		//nothing
	}

	@Override
	public void keyTyped(KeyEvent e) {
		if( closeEasily && e.getKeyCode() == KeyEvent.VK_ESCAPE )
			close();
	}

	@Override
	public void windowActivated(WindowEvent arg0) {
		//nothing
	}

	@Override
	public void windowClosed(WindowEvent arg0) {
		close();
	}

	@Override
	public void windowClosing(WindowEvent arg0) {
		close();
	}

	@Override
	public void windowDeactivated(WindowEvent arg0) {
		//nothing
	}

	@Override
	public void windowDeiconified(WindowEvent arg0) {
		//nothing
	}

	@Override
	public void windowIconified(WindowEvent arg0) {
		//nothing
	}

	@Override
	public void windowOpened(WindowEvent arg0) {
		//nothing
	}
}
